@@ -12,11 +12,7 @@ def make_console_script(package_name: str, main: Callable):
     :param main:
     :return:
     """
-    return "{}={}:{}".format(
-        package_name,
-        getattr(main, '__module__'),
-        main.__name__,
-    )
+    return f"{package_name}={getattr(main, '__module__')}:{main.__name__,}"
 
 
 def array_indented(level: int, array: List[str], quote_char='\'', comma_after=False) -> str:
@@ -56,7 +52,7 @@ def dict_indented(level: int, dictionary: Dict[str, List[int]], quote_char='\'',
             v=v,
         )
     spaces = ((level * 4) * " ")
-    out += "{}}}".format(spaces)
+    out += f"{spaces}}}}}"
     if comma_after:
         out += ","
     return out
